@@ -235,6 +235,80 @@ where
         }
     }
 
+    pub(crate) fn split_left<F>(
+        &self,
+        measure: V::Measure,
+        pred: &mut F,
+    ) -> (Tree<R, V>, Node<R, V>)
+    where
+        F: FnMut(&V::Measure) -> bool,
+    {
+        match self {
+            Empty => unreachable!("recursive split of finger-tree called on empty tree"),
+            Single(value) => (Tree::empty(), value.clone()),
+            Deep(deep) => {
+                // left
+                let left_measure = measure.join(&deep.left.measure());
+                if pred(&left_measure) {
+                    let (l, x, _r) = deep.left.split(measure, pred);
+                    return (Tree::from(l), x.clone());
+                }
+                // spine
+                let spine_measure = left_measure.join(&deep.spine.measure());
+                if pred(&spine_measure) {
+                    let (sl, sx) = deep.spine.split_left(left_measure.clone(), pred);
+                    let sx = Digit::from(&sx);
+                    let (l, x, _r) = sx.split(left_measure.join(&sl.measure()), pred);
+                    return (Self::deep_right(&deep.left, &sl, l), x.clone());
+                }
+                // right
+                let (l, x, _r) = deep.right.split(spine_measure, pred);
+                (Self::deep_right(&deep.left, &deep.spine, l), x.clone())
+            }
+        }
+    }
+
+    pub(crate) fn split_right<F>(
+        &self,
+        measure: V::Measure,
+        pred: &mut F,
+    ) -> (V::Measure, Node<R, V>, Tree<R, V>)
+    where
+        F: FnMut(&V::Measure) -> bool,
+    {
+        match self {
+            Empty => unreachable!("recursive split of finger-tree called on empty tree"),
+            Single(value) => (measure, value.clone(), Tree::empty()),
+            Deep(deep) => {
+                // left
+                let left_measure = measure.join(&deep.left.measure());
+                if pred(&left_measure) {
+                    let (l, x, r) = deep.left.split(measure.to_owned(), pred);
+                    return (
+                        measure.join(&l.measure()),
+                        x.clone(),
+                        Self::deep_left(r, &deep.spine, &deep.right),
+                    );
+                }
+                // spine
+                let spine_measure = left_measure.join(&deep.spine.measure());
+                if pred(&spine_measure) {
+                    let (slm, sx, sr) = deep.spine.split_right(left_measure.clone(), pred);
+                    let sx = Digit::from(&sx);
+                    let (l, x, r) = sx.split(slm.to_owned(), pred);
+                    return (
+                        slm.join(&l.measure()),
+                        x.clone(),
+                        Self::deep_left(r, &sr, &deep.right),
+                    );
+                }
+                // right
+                let (l, x, r) = deep.right.split(spine_measure.to_owned(), pred);
+                (spine_measure.join(&l.measure()), x.clone(), Tree::from(r))
+            }
+        }
+    }
+
     fn push_left_many(self, iter: &mut dyn Iterator<Item = Node<R, V>>) -> Self {
         match iter.next() {
             None => self,
